#*****************************************************************************************
#*** package-level documentation *********************************************************
#*****************************************************************************************
#' scdensity: Shape-constrained kernel density estimation.
#'
#' This package computes one-dimensional Gaussian kernel density estimates subject to a
#' variety of shape constraints, including unimodality, bimodality, symmetry, and others.
#'
#' All of the package's functionality can be accessed through the function
#' [scdensity::scdensity()].  See that function's help file.  The function is used
#' just like [stats::density()], but with extra arguments for handling the constraints.
#'
#' @keywords internal
#' @aliases scdensity-package NULL
"_PACKAGE"

